package	jp.co.sds_corp.syslog.filter;

import java.net.InetAddress;

import jp.co.sds_corp.syslog.SyslogEvent;
import jp.co.sds_corp.util.config.IConfiguration;
import jp.co.sds_corp.util.syslog.SyslogMsg;

/**
* syslogの送信元によりフィルタリングを行ないます。
XMLは以下の形式です。
<TABLE BORDER="1">
	<TR><TH>要素</TH><TH>必須</TH><TH>説明</TH><TH>備考</TH></TR>
	<TR>
		<TD>Source</TD>
		<TD>&nbsp;</TD>
		<TD>syslogの送信元を指定</TD>
		<TD>&nbsp;</TD>
	</TR>
	<TR>
		<TD>Exclude</TD>
		<TD>&nbsp;</TD>
		<TD>除外フラグ
			(true:条件に合致すれば除外/false:条件に合致するもののみ対象)</TD>
		<TD>指定されない場合はfalse</TD>
	</TR>
	<TR>
		<TD>Valid</TD>
		<TD>&nbsp;</TD>
		<TD>有効フラグ(true:有効/false:無効)</TD>
		<TD>指定されない場合はtrue</TD>
	</TR>
</TABLE>
<PRE>
&lt;Filter class="jp.co.sds_corp.syslog.filter.SourceFilter"&gt;
	&lt;Source&gt;192.168.0.1&lt;/Source&gt;
	&lt;Exclude&gt;true&lt;/Exclude&gt;
	&lt;Valid&gt;false&lt;/Valid&gt;
&lt;/Filter&gt;
</PRE>
*/
public class SourceFilter extends AbstractFilter
{
	private static final long serialVersionUID = 1L;
	String	source;
	InetAddress	address;

	/**
	* 指定された初期情報で初期化します。
	* @param    config  初期情報
	*/
	public void init( IConfiguration config ) throws Exception {
		super.init( config );
		String var;
		var = config.get( "Source", null );
		if ( var != null ) {
			setSource( var );
		}
	}

	/**
	* syslogのがこのフィルタの条件に合致するかを検査します。
	* @param	e		データ受信イベント
	*/
	public boolean match( SyslogEvent e ) {
		SyslogMsg msg = e.getMessage();
		if ( address != null ) {
			if ( !msg.getAddress().equals( address )) {
				return false;
			}
		}
		return true;
	}

	/**
	* 設定内容の文字列表現を返します。
	*/
	public String paramString() {
		String ret = "{";
		ret += super.paramString();
		if ( source != null ) {
			ret += source;
		}
		ret += "}";
		return ret;
	}

	/**
	* 設定されている内容をXML形式で出力します。
	* @param	config	親ノード
	*/
	public void saveConfig( IConfiguration config ) {
		super.saveConfig( config );
		config.addChild( "Source", getSource() );
	}

	/**
	* メッセージの送信元(source)を設定します。
	* @param	var		設定するデータ
	*/
	public void setSource( String var ) throws Exception {
		this.address = InetAddress.getByName( var );
		this.source = var ;
	}
	/**
	* メッセージの送信元(source)を取得します。
	* @return	sourceの内容
	*/
	public String getSource() {
		return source;
	}

}
